.. _cisco.nxos.nxos_cliconf:


***************
cisco.nxos.nxos
***************

**Use NX-OS cliconf to run commands on Cisco NX-OS platform**


Version added: 1.0.0

.. contents::
   :local:
   :depth: 1


Synopsis
--------
- This nxos plugin provides low level abstraction apis for sending and receiving CLI commands from Cisco NX-OS network devices.











Status
------


Authors
~~~~~~~

- Ansible Networking Team


.. hint::
    Configuration entries for each entry type have a low to high priority order. For example, a variable that is lower in the list will override a variable that is higher up.
